@@ -1,4 +1,4 @@
-#!/usr/bin/python3
+#!/usr/bin/env python
 
 from sys import stderr, exit, argv, maxsize
 from copy import deepcopy
@@ -8,9 +8,6 @@ from random import randint
 from math import ceil
 import logging as log
 
-ALPHA = 1
-
-
 class BothStrands:
 
     def __eq__(self, x):
@@ -59,9 +56,9 @@ class Run:
         return len(self.weight)
 
     def __str__(self):
-        return 'G1:%s-%s G2:%s-%s %s (%.5f)' % (self.startG1, self.endG1,
+        return 'G1:%s-%s G2:%s-%s %s' % (self.startG1, self.endG1,
                                                 self.startG2, self.endG2,
-                                                self.direction, self.getWeight(ALPHA))
+                                                self.direction)
 
 
 def readDistsAndOrder(dist_file, edgeThreshold):
@@ -133,11 +130,11 @@ def sort_genome(chrom_pos):
     return telomeres, g
 
 
-def insertIntoRunList(runs, runList):
-    keys = [x.getWeight(ALPHA) for x in runList]
+def insertIntoRunList(runs, runList, alpha):
+    keys = [x.getWeight(alpha) for x in runList]
     for run in runs:
-        i = bisect(keys, run.getWeight(ALPHA))
-        keys.insert(i, run.getWeight(ALPHA))
+        i = bisect(keys, run.getWeight(alpha))
+        keys.insert(i, run.getWeight(alpha))
         runList.insert(i, run)
 
 
@@ -363,7 +360,7 @@ def replaceByNew(g1_runs, g2_runs, i, j, r_old, r_new):
             break
 
 
-def doMatching(g1, g2, g1_runs, g2_runs, m, runList):
+def doMatching(g1, g2, g1_runs, g2_runs, m, runList, alpha):
     g1pos = dict(zip(g1, range(len(g1))))
     g2pos = dict(zip(g2, range(len(g2))))
     newRuns = set()
@@ -455,6 +452,7 @@ def doMatching(g1, g2, g1_runs, g2_runs, m, runList):
                     g1_runs[g1pos[r.endG1]].remove(r)
                 r.startG2 = g2[j]
                 log.info('Divided overlapping run in %s and %s' % (r_new, r))
+
                 replaceByNew(g1_runs, g2_runs, g1pos[r_new.startG1],
                              g2pos[r_new.startG2], r, r_new)
                 newRuns.add(r_new)
@@ -480,10 +478,10 @@ def doMatching(g1, g2, g1_runs, g2_runs, m, runList):
                 newRuns.add(r)
             elif r in newRuns:
                 newRuns.remove(r)
-    insertIntoRunList(newRuns, runList)
+    insertIntoRunList(newRuns, runList, alpha)
 
 
-def mergeRuns(mod_g1, g1, g2, g1_runs, g2_runs, runList, alreadyMatched):
+def mergeRuns(mod_g1, g1, g2, g1_runs, g2_runs, runList, alreadyMatched, alpha):
     g1pos = dict(zip(g1, range(len(g1))))
     g2pos = dict(zip(g2, range(len(g2))))
 
@@ -504,9 +502,9 @@ def mergeRuns(mod_g1, g1, g2, g1_runs, g2_runs, runList, alreadyMatched):
         # points (mod_g1) can be processed.
 
         for r1, r2 in product(sorted(g1_runs[i].difference(g1_runs[i+1]),
-                                     key=lambda x: x.getWeight(ALPHA), reverse=True),
+                                     key=lambda x: x.getWeight(alpha), reverse=True),
                               sorted(g1_runs[i+1].difference(g1_runs[i]),
-                                     key=lambda x: x.getWeight(ALPHA), reverse=True)):
+                                     key=lambda x: x.getWeight(alpha), reverse=True)):
             if r1.endG1 == g1[i] and r2.startG1 == g1[i+1] and \
                     r1.direction == r2.direction and \
                     r1.endG1[0] == r2.startG1[0] and \
@@ -538,7 +536,7 @@ def mergeRuns(mod_g1, g1, g2, g1_runs, g2_runs, runList, alreadyMatched):
                     if r1 in alreadyMatched:
                         alreadyMatched.remove(r1)
                     # redo matching in case r1 xor r2 were not in matching before
-                    insertIntoRunList(newRuns, runList)
+                    insertIntoRunList(newRuns, runList, alpha)
                     return r2, set(mod_g1[x+1:])
                 if r2 in alreadyMatched:
                     # actually, both are already matched
@@ -548,7 +546,7 @@ def mergeRuns(mod_g1, g1, g2, g1_runs, g2_runs, runList, alreadyMatched):
                     # none is matched
                     newRuns.add(r2)
 
-    insertIntoRunList(newRuns, runList)
+    insertIntoRunList(newRuns, runList, alpha)
     return None, []
 
 
@@ -567,7 +565,7 @@ def removeSingleGenes(genome, genome_runs):
     return del_res, mod_res
 
 
-def findRandomRunSequence(g1, g2, dists, topXperCent):
+def findRandomRunSequence(g1, g2, dists, topXperCent, alpha):
     g2dists = dict()
     for g1i, x in list(dists.items()):
         for g2j, d in list(x.items()):
@@ -585,11 +583,12 @@ def findRandomRunSequence(g1, g2, dists, topXperCent):
     g1_runs, g2_runs, runs = getAllRuns(g1, g2, dists)
     log.info('Found %s runs.' % len(runs))
     # sort
-    runList = sorted(runs, key=lambda x: x.getWeight(ALPHA))
+    runList = sorted(runs, key=lambda x: x.getWeight(alpha))
 
     res = set()
     while runList:
-        noOfAdjacencies = len([x for x in runList if x.getWeight(ALPHA) and x.getWeight(ALPHA) or 0])
+        noOfAdjacencies = len([x for x in runList if x.getWeight(alpha) and
+            x.getWeight(alpha) or 0])
         if noOfAdjacencies:
             randPos = randint(1, ceil(noOfAdjacencies * topXperCent))
         else:
@@ -601,7 +600,7 @@ def findRandomRunSequence(g1, g2, dists, topXperCent):
         while mx:
             res.add(mx)
             # update run list
-            doMatching(g1, g2, g1_runs, g2_runs, mx, runList)
+            doMatching(g1, g2, g1_runs, g2_runs, mx, runList, alpha)
             del_g1, new_mod_g1 = removeSingleGenes(g1, g1_runs)
             if del_g1:
                 log.info('Zombie genes removed from G1: %s' % ', '.join(map(str, del_g1)))
@@ -631,7 +630,7 @@ def findRandomRunSequence(g1, g2, dists, topXperCent):
                                 mod_g1.add(g1[g1pos[g1i]-1])
             # merge runs
             mx, mod_g1 = mergeRuns(mod_g1, g1, g2, g1_runs, g2_runs,
-                                   runList, res)
+                                   runList, res, alpha)
 
     if res:
         log.info('Matching finished. Longest run size is %s.' % (max(list(map(len, res)))))
@@ -642,7 +641,7 @@ def findRandomRunSequence(g1, g2, dists, topXperCent):
 
 
 def repeatMatching(g1, g2, g1_mod, g2_mod, g1_runs, g2_runs, dists, repMatching,
-                   minCsSize, topXperCent):
+                   minCsSize, topXperCent, alpha):
 
     g1_mod_res = g1_mod
     g2_mod_res = g2_mod
@@ -680,7 +679,7 @@ def repeatMatching(g1, g2, g1_mod, g2_mod, g1_runs, g2_runs, dists, repMatching,
                      (noReps-repMatching+2))
             break
 
-        g1_mod, g2_mod, g1_runs, g2_runs, selectedRuns = findRandomRunSequence(g1, g2, dists, topXperCent)
+        g1_mod, g2_mod, g1_runs, g2_runs, selectedRuns = findRandomRunSequence(g1, g2, dists, topXperCent, alpha)
         checkMatching(g1_mod, g2_mod, g1_runs, g2_runs, selectedRuns, dists)
 
         log.info('Obtained %s adjacencies in matching of size %s from iteration %s.' %
@@ -793,7 +792,6 @@ if __name__ == '__main__':
     cli.add_argument('-a', '--alpha', type=float, metavar='F', default=0.5)
     cli.add_argument('dist_file')
     args = cli.parse_args()
-    AlPHA = args.alpha
     repMatching = args.repeat_matching
     if repMatching > 0:
         repMatching -= 1
@@ -802,14 +800,16 @@ if __name__ == '__main__':
                     format="%(levelname)s\t%(asctime)s\t++ %(message)s")
 
     multiChrom, g1, g2, dists = readDistsAndOrder(args.dist_file, args.edge_weight_threshold)
-    g1_mod, g2_mod, g1_runs, g2_runs, selectedRuns = findRandomRunSequence(g1, g2, dists, args.greedy)
+    g1_mod, g2_mod, g1_runs, g2_runs, selectedRuns = findRandomRunSequence(g1,
+            g2, dists, args.greedy, args.alpha)
     checkMatching(g1_mod, g2_mod, g1_runs, g2_runs, selectedRuns, dists)
 
     # calculate number of breakpoints only from result of the first matching
     bkp = len(selectedRuns) - 1
 
     g1_mod, g2_mod, g1_runs, g2_runs, selectedRuns_new = repeatMatching(g1, g2,
-            g1_mod, g2_mod, g1_runs, g2_runs, dists, repMatching, args.min_cs_size, args.greedy)
+            g1_mod, g2_mod, g1_runs, g2_runs, dists, repMatching,
+            args.min_cs_size, args.greedy, args.alpha)
 
     selectedRuns.update(selectedRuns_new)
 
@@ -833,3 +833,4 @@ if __name__ == '__main__':
 
     print('#bkp\t#edg\tadj\tedg')
     print('%s\t%s\t%.6f\t%.6f' % (bkp, edg, wAdj, wEdg))
+
